views

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CredentialListView

type CredentialListView struct {
	// contains filtered or unexported fields
}

CredentialListView is a view that displays a table of credentials.

func NewCredentialListView

func NewCredentialListView() *CredentialListView

NewCredentialListView creates a new CredentialListView.

func (*CredentialListView) Render

func (d *CredentialListView) Render() string

Render renders the view.

func (*CredentialListView) WithCredentials

WithCredentials adds credentials to the view.

type DeviceInfoView

type DeviceInfoView struct {
	// contains filtered or unexported fields
}

DeviceInfoView is a view that displays detailed information about a security key.

func NewDeviceInfoView

NewDeviceInfoView creates a new DeviceInfoView.

func (*DeviceInfoView) Render

func (v *DeviceInfoView) Render() string

Render renders the view.

func (*DeviceInfoView) WithRetries

func (v *DeviceInfoView) WithRetries(pinRetries uint, uvRetries uint, hasUV bool) *DeviceInfoView

WithRetries sets the PIN and UV retries for the view.

type DevicesListView

type DevicesListView struct {
	// contains filtered or unexported fields
}

DevicesListView is a view that displays a table of connected security keys.

func NewDevicesListView

func NewDevicesListView() *DevicesListView

NewDevicesListView creates a new DevicesListView.

func (*DevicesListView) Render

func (d *DevicesListView) Render() string

Render renders the view.

func (*DevicesListView) WithDevices

func (d *DevicesListView) WithDevices(devs ...fido2.DeviceDescriptor) *DevicesListView

WithDevices adds devices to the view.

Jump to